@@ -113,58 +113,29 @@ struct merged_symbol {
 
 /*
  * The number of merged_symbol structrures in a merged_symbol_list.
+ * THE VALUE OF THIS MACRO MUST BE AN ODD NUMBER (NOT A POWER OF TWO).
  */
 #ifndef RLD
-#define NSYMBOLS 20001
+#define NSYMBOLS 2001
 #else
 #define NSYMBOLS 201
 #endif /* RLD */
 /* The number of size of the hash table in a merged_symbol_list */
 #define SYMBOL_LIST_HASH_SIZE	(NSYMBOLS * 2)
 
-/* The number of buckets for conflicts */
-#define SYMBOL_CHUNK_SIZE 10
-
-/* The collection of buckets for conflicting hash values */
-struct merged_symbol_chunk
-{
-    /* the buckets */
-    struct merged_symbol symbols[SYMBOL_CHUNK_SIZE];
-
-    /*
-     * next chunk (if this is not null, it means all of the buckets of this
-     * chunk are full)
-     */
-    struct merged_symbol_chunk *next;
-};
-
 /*
- * The block that has the hash table and a pointer to symbol list.
- */
-struct merged_symbol_root {
-    /* the hashed array of chunks */
-    struct merged_symbol_chunk chunks[SYMBOL_LIST_HASH_SIZE];
-
-    /* the list of used symbols */
-    struct merged_symbol_list *list;
-};
-
-/*
- * The symbol list is the list of symbols that have been used. It's a compact
- * flat array of pointers into the sparse hash table.
+ * The structure to hold a chunk the list of merged symbol.
  */
 struct merged_symbol_list {
-    /* pointers to symbols in the merged_symbol_chunk */
-    struct merged_symbol *symbols[SYMBOL_LIST_HASH_SIZE];
-
-    /* next free location in the symbols array */
-    unsigned long used;
-
-    /* next linked symbol list (NULL means no more) */
-    struct merged_symbol_list *next;
+    struct merged_symbol	/* the merged_symbol structures in this chunk */
+	merged_symbols[NSYMBOLS];
+    unsigned long used;		/* the number used in this chunk */
+    struct merged_symbol	/* pointer to the hash table for this chunk */
+	**hash_table;		/*  (it is a pointer so it can be free'ed) */
+    struct merged_symbol_list	/* the next chunk (NULL in no more chunks) */
+	*next;
 };
 
-
 /* the blocks that store the strings; allocated as needed */
 struct string_block {
     unsigned long size;		/* the number of bytes in this block */
@@ -220,7 +191,7 @@ struct common_symbol {
  * count of the merged symbols.  The count of merged symbols referenced only
  * from dylibs will not be in the output file.
  */
-__private_extern__ struct merged_symbol_root *merged_symbol_root;
+__private_extern__ struct merged_symbol_list *merged_symbol_lists;
 __private_extern__ unsigned long nmerged_symbols;
 __private_extern__ unsigned long nmerged_private_symbols;
 __private_extern__ unsigned long nmerged_symbols_referenced_only_from_dylibs;
@@ -354,14 +325,12 @@ __private_extern__ void merge_symbols(
     void);
 __private_extern__ struct merged_symbol *command_line_symbol(
     char *symbol_name);
-__private_extern__ struct merged_symbol *lookup_symbol(
+__private_extern__ struct merged_symbol **lookup_symbol(
     char *symbol_name);
 __private_extern__ void command_line_indr_symbol(
     char *symbol_name,
     char *indr_symbol_name);
 #ifndef RLD
-__private_extern__ void hash_instrument(
-    void);
 __private_extern__ void merge_dylib_module_symbols(
     struct dynamic_library *dynamic_library);
 __private_extern__ void merge_bundle_loader_symbols(
